This fixes bug 25673, so Classpath will now claim that "gkr" is the default keystore type, instead of "jks."

2006-04-18  Casey Marshall  <[EMAIL PROTECTED]>

        Fixes PR classpath/25673        
        * java/security/KeyStore.java (getDefaultType): return "gkr" if no
        property is set. Update JavaDoc to reflect this.


Committed.

Index: java/security/KeyStore.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/security/KeyStore.java,v
retrieving revision 1.12
diff -u -B -b -r1.12 KeyStore.java
--- java/security/KeyStore.java 2 Jul 2005 20:32:40 -0000       1.12
+++ java/security/KeyStore.java 19 Apr 2006 01:28:13 -0000
@@ -212,7 +212,7 @@
   /**
    * Returns the default KeyStore type. This method looks up the
    * type in &lt;JAVA_HOME&gt;/lib/security/java.security with the 
    * property "keystore.type" or if that fails then "jks" .
    */
   public static final String getDefaultType()
   {
@@ -221,7 +221,7 @@
     String tmp = Security.getProperty("keystore.type");
 
     if (tmp == null)
-      tmp = "jks";
+      tmp = "gkr";
 
     return tmp;
   }
@@ -212,7 +212,7 @@
    * Returns the default KeyStore type. This method looks up the
    * type in &lt;JAVA_HOME&gt;/lib/security/java.security with the 
-   * property "keystore.type" or if that fails then "jks" .
+   * property "keystore.type" or if that fails then "gkr" .
    */
   public static final String getDefaultType()

Attachment: PGP.sig
Description: This is a digitally signed message part

Reply via email to